/* -*-c-*-
 *
 * Keyword-argument support functions requiring a hosted implementation
 *
 * (c) 2015 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of the Sensible Object Design, an object system for C.
 *
 * SOD is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * SOD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with SOD; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

/*----- Header files ------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>

/*----- Main code ---------------------------------------------------------*/

/* --- @kw_defunknown@ --- *
 *
 * Arguments:	@const char *set@ = keyword set name
 *		@const char *kw@ = the offending keyword name
 *
 * Returns:	Doesn't.
 *
 * Use:		This is the default @kw_unkhook@ hook function.
 *
 *		In a hosted implementation, this function reports an internal
 *		error to stderr about the unknown keyword and calls @abort@.
 *		It is an implementation responsibility for freestanding
 *		implementations wanting to use this keyword argument
 *		mechanism.
 */

void kw_defunknown(const char *set, const char *kw)
{
  fprintf(stderr, "INTERNAL ERROR: unknown `%s' keyword argument `%s'\n",
	  set, kw);
  abort();
}

/* --- @kw__hookfailed@ --- *
 *
 * Arguments:	---
 *
 * Returns:	Doesn't.
 *
 * Use:		Called by @kw_unknown@ if the @kw_unkhook@ hook function
 *		returns.
 *
 *		User code is not expected to call this function.  It exists
 *		as an implementation respensibility for freestanding
 *		implementations wanting to use this keyword argument
 *		mechanism.
 */

void kw__hookfailed(void)
{
  fprintf(stderr, "INTERNAL ERROR: `kw_unkhook' hook function returned\n");
  abort();
}

/*----- That's all, folks -------------------------------------------------*/
